"""
    Cluster API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.cluster_bios_info import ClusterBiosInfo
from pensando_dss.psm.model.cluster_cpu_info import ClusterCPUInfo
from pensando_dss.psm.model.cluster_mem_info import ClusterMemInfo
from pensando_dss.psm.model.cluster_os_info import ClusterOsInfo
from pensando_dss.psm.model.cluster_storage_info import ClusterStorageInfo
globals()['ClusterBiosInfo'] = ClusterBiosInfo
globals()['ClusterCPUInfo'] = ClusterCPUInfo
globals()['ClusterMemInfo'] = ClusterMemInfo
globals()['ClusterOsInfo'] = ClusterOsInfo
globals()['ClusterStorageInfo'] = ClusterStorageInfo
from pensando_dss.psm.psm.model.cluster_dsc_info import ClusterDSCInfo


class TestClusterDSCInfo(unittest.TestCase):
    """ClusterDSCInfo unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testClusterDSCInfo(self):
        """Test ClusterDSCInfo"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ClusterDSCInfo()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Diagnostics API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import psm
from pensando_dss.psm.api.diagnostics_v1_api import DiagnosticsV1Api  # noqa: E501


class TestDiagnosticsV1Api(unittest.TestCase):
    """DiagnosticsV1Api unit test stubs"""

    def setUp(self):
        self.api = DiagnosticsV1Api()  # noqa: E501

    def tearDown(self):
        pass

    def test_debug(self):
        """Test case for debug

        Request Diagnostics information for a module  # noqa: E501
        """
        pass

    def test_get_module(self):
        """Test case for get_module

        Get Module object  # noqa: E501
        """
        pass

    def test_label_module(self):
        """Test case for label_module

        Label Module object  # noqa: E501
        """
        pass

    def test_list_module(self):
        """Test case for list_module

        List Module objects  # noqa: E501
        """
        pass

    def test_update_module(self):
        """Test case for update_module

        Update Module object  # noqa: E501
        """
        pass

    def test_watch_module(self):
        """Test case for watch_module

        Watch Module objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Monitoring API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import psm
from pensando_dss.psm.api.monitoring_v1_api import MonitoringV1Api  # noqa: E501


class TestMonitoringV1Api(unittest.TestCase):
    """MonitoringV1Api unit test stubs"""

    def setUp(self):
        self.api = MonitoringV1Api()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_alert_destination(self):
        """Test case for add_alert_destination

        Create AlertDestination object  # noqa: E501
        """
        pass

    def test_add_alert_destination1(self):
        """Test case for add_alert_destination1

        Create AlertDestination object  # noqa: E501
        """
        pass

    def test_add_alert_policy(self):
        """Test case for add_alert_policy

        Create AlertPolicy object  # noqa: E501
        """
        pass

    def test_add_alert_policy1(self):
        """Test case for add_alert_policy1

        Create AlertPolicy object  # noqa: E501
        """
        pass

    def test_add_archive_request(self):
        """Test case for add_archive_request

        Create ArchiveRequest object  # noqa: E501
        """
        pass

    def test_add_archive_request1(self):
        """Test case for add_archive_request1

        Create ArchiveRequest object  # noqa: E501
        """
        pass

    def test_add_audit_policy(self):
        """Test case for add_audit_policy

        Create AuditPolicy object  # noqa: E501
        """
        pass

    def test_add_audit_policy1(self):
        """Test case for add_audit_policy1

        Create AuditPolicy object  # noqa: E501
        """
        pass

    def test_add_event_policy(self):
        """Test case for add_event_policy

        Create EventPolicy object  # noqa: E501
        """
        pass

    def test_add_event_policy1(self):
        """Test case for add_event_policy1

        Create EventPolicy object  # noqa: E501
        """
        pass

    def test_add_flow_export_policy(self):
        """Test case for add_flow_export_policy

        Create FlowExportPolicy object  # noqa: E501
        """
        pass

    def test_add_flow_export_policy1(self):
        """Test case for add_flow_export_policy1

        Create FlowExportPolicy object  # noqa: E501
        """
        pass

    def test_add_fwlog_policy(self):
        """Test case for add_fwlog_policy

        Create FwlogPolicy object  # noqa: E501
        """
        pass

    def test_add_fwlog_policy1(self):
        """Test case for add_fwlog_policy1

        Create FwlogPolicy object  # noqa: E501
        """
        pass

    def test_add_mirror_session(self):
        """Test case for add_mirror_session

        Create MirrorSession object  # noqa: E501
        """
        pass

    def test_add_mirror_session1(self):
        """Test case for add_mirror_session1

        Create MirrorSession object  # noqa: E501
        """
        pass

    def test_add_stats_alert_policy(self):
        """Test case for add_stats_alert_policy

        Create StatsAlertPolicy object  # noqa: E501
        """
        pass

    def test_add_stats_alert_policy1(self):
        """Test case for add_stats_alert_policy1

        Create StatsAlertPolicy object  # noqa: E501
        """
        pass

    def test_add_tech_support_request(self):
        """Test case for add_tech_support_request

        Create TechSupportRequest object  # noqa: E501
        """
        pass

    def test_add_troubleshooting_session(self):
        """Test case for add_troubleshooting_session

        Create TroubleshootingSession object  # noqa: E501
        """
        pass

    def test_add_troubleshooting_session1(self):
        """Test case for add_troubleshooting_session1

        Create TroubleshootingSession object  # noqa: E501
        """
        pass

    def test_cancel(self):
        """Test case for cancel

        """
        pass

    def test_cancel1(self):
        """Test case for cancel1

        """
        pass

    def test_delete_alert_destination(self):
        """Test case for delete_alert_destination

        Delete AlertDestination object  # noqa: E501
        """
        pass

    def test_delete_alert_destination1(self):
        """Test case for delete_alert_destination1

        Delete AlertDestination object  # noqa: E501
        """
        pass

    def test_delete_alert_policy(self):
        """Test case for delete_alert_policy

        Delete AlertPolicy object  # noqa: E501
        """
        pass

    def test_delete_alert_policy1(self):
        """Test case for delete_alert_policy1

        Delete AlertPolicy object  # noqa: E501
        """
        pass

    def test_delete_archive_request(self):
        """Test case for delete_archive_request

        Delete ArchiveRequest object  # noqa: E501
        """
        pass

    def test_delete_archive_request1(self):
        """Test case for delete_archive_request1

        Delete ArchiveRequest object  # noqa: E501
        """
        pass

    def test_delete_audit_policy(self):
        """Test case for delete_audit_policy

        Delete AuditPolicy object  # noqa: E501
        """
        pass

    def test_delete_audit_policy1(self):
        """Test case for delete_audit_policy1

        Delete AuditPolicy object  # noqa: E501
        """
        pass

    def test_delete_event_policy(self):
        """Test case for delete_event_policy

        Delete EventPolicy object  # noqa: E501
        """
        pass

    def test_delete_event_policy1(self):
        """Test case for delete_event_policy1

        Delete EventPolicy object  # noqa: E501
        """
        pass

    def test_delete_flow_export_policy(self):
        """Test case for delete_flow_export_policy

        Delete FlowExportPolicy object  # noqa: E501
        """
        pass

    def test_delete_flow_export_policy1(self):
        """Test case for delete_flow_export_policy1

        Delete FlowExportPolicy object  # noqa: E501
        """
        pass

    def test_delete_fwlog_policy(self):
        """Test case for delete_fwlog_policy

        Delete FwlogPolicy object  # noqa: E501
        """
        pass

    def test_delete_fwlog_policy1(self):
        """Test case for delete_fwlog_policy1

        Delete FwlogPolicy object  # noqa: E501
        """
        pass

    def test_delete_mirror_session(self):
        """Test case for delete_mirror_session

        Delete MirrorSession object  # noqa: E501
        """
        pass

    def test_delete_mirror_session1(self):
        """Test case for delete_mirror_session1

        Delete MirrorSession object  # noqa: E501
        """
        pass

    def test_delete_stats_alert_policy(self):
        """Test case for delete_stats_alert_policy

        Delete StatsAlertPolicy object  # noqa: E501
        """
        pass

    def test_delete_stats_alert_policy1(self):
        """Test case for delete_stats_alert_policy1

        Delete StatsAlertPolicy object  # noqa: E501
        """
        pass

    def test_delete_tech_support_request(self):
        """Test case for delete_tech_support_request

        Delete TechSupportRequest object  # noqa: E501
        """
        pass

    def test_delete_troubleshooting_session(self):
        """Test case for delete_troubleshooting_session

        Delete TroubleshootingSession object  # noqa: E501
        """
        pass

    def test_delete_troubleshooting_session1(self):
        """Test case for delete_troubleshooting_session1

        Delete TroubleshootingSession object  # noqa: E501
        """
        pass

    def test_get_alert(self):
        """Test case for get_alert

        Get Alert object  # noqa: E501
        """
        pass

    def test_get_alert1(self):
        """Test case for get_alert1

        Get Alert object  # noqa: E501
        """
        pass

    def test_get_alert_destination(self):
        """Test case for get_alert_destination

        Get AlertDestination object  # noqa: E501
        """
        pass

    def test_get_alert_destination1(self):
        """Test case for get_alert_destination1

        Get AlertDestination object  # noqa: E501
        """
        pass

    def test_get_alert_policy(self):
        """Test case for get_alert_policy

        Get AlertPolicy object  # noqa: E501
        """
        pass

    def test_get_alert_policy1(self):
        """Test case for get_alert_policy1

        Get AlertPolicy object  # noqa: E501
        """
        pass

    def test_get_archive_request(self):
        """Test case for get_archive_request

        Get ArchiveRequest object  # noqa: E501
        """
        pass

    def test_get_archive_request1(self):
        """Test case for get_archive_request1

        Get ArchiveRequest object  # noqa: E501
        """
        pass

    def test_get_audit_policy(self):
        """Test case for get_audit_policy

        Get AuditPolicy object  # noqa: E501
        """
        pass

    def test_get_audit_policy1(self):
        """Test case for get_audit_policy1

        Get AuditPolicy object  # noqa: E501
        """
        pass

    def test_get_event_policy(self):
        """Test case for get_event_policy

        Get EventPolicy object  # noqa: E501
        """
        pass

    def test_get_event_policy1(self):
        """Test case for get_event_policy1

        Get EventPolicy object  # noqa: E501
        """
        pass

    def test_get_flow_export_policy(self):
        """Test case for get_flow_export_policy

        Get FlowExportPolicy object  # noqa: E501
        """
        pass

    def test_get_flow_export_policy1(self):
        """Test case for get_flow_export_policy1

        Get FlowExportPolicy object  # noqa: E501
        """
        pass

    def test_get_fwlog_policy(self):
        """Test case for get_fwlog_policy

        Get FwlogPolicy object  # noqa: E501
        """
        pass

    def test_get_fwlog_policy1(self):
        """Test case for get_fwlog_policy1

        Get FwlogPolicy object  # noqa: E501
        """
        pass

    def test_get_mirror_session(self):
        """Test case for get_mirror_session

        Get MirrorSession object  # noqa: E501
        """
        pass

    def test_get_mirror_session1(self):
        """Test case for get_mirror_session1

        Get MirrorSession object  # noqa: E501
        """
        pass

    def test_get_stats_alert_policy(self):
        """Test case for get_stats_alert_policy

        Get StatsAlertPolicy object  # noqa: E501
        """
        pass

    def test_get_stats_alert_policy1(self):
        """Test case for get_stats_alert_policy1

        Get StatsAlertPolicy object  # noqa: E501
        """
        pass

    def test_get_tech_support_request(self):
        """Test case for get_tech_support_request

        Get TechSupportRequest object  # noqa: E501
        """
        pass

    def test_get_troubleshooting_session(self):
        """Test case for get_troubleshooting_session

        Get TroubleshootingSession object  # noqa: E501
        """
        pass

    def test_get_troubleshooting_session1(self):
        """Test case for get_troubleshooting_session1

        Get TroubleshootingSession object  # noqa: E501
        """
        pass

    def test_label_alert(self):
        """Test case for label_alert

        Label Alert object  # noqa: E501
        """
        pass

    def test_label_alert1(self):
        """Test case for label_alert1

        Label Alert object  # noqa: E501
        """
        pass

    def test_label_alert_destination(self):
        """Test case for label_alert_destination

        Label AlertDestination object  # noqa: E501
        """
        pass

    def test_label_alert_destination1(self):
        """Test case for label_alert_destination1

        Label AlertDestination object  # noqa: E501
        """
        pass

    def test_label_alert_policy(self):
        """Test case for label_alert_policy

        Label AlertPolicy object  # noqa: E501
        """
        pass

    def test_label_alert_policy1(self):
        """Test case for label_alert_policy1

        Label AlertPolicy object  # noqa: E501
        """
        pass

    def test_label_event_policy(self):
        """Test case for label_event_policy

        Label EventPolicy object  # noqa: E501
        """
        pass

    def test_label_event_policy1(self):
        """Test case for label_event_policy1

        Label EventPolicy object  # noqa: E501
        """
        pass

    def test_label_flow_export_policy(self):
        """Test case for label_flow_export_policy

        Label FlowExportPolicy object  # noqa: E501
        """
        pass

    def test_label_flow_export_policy1(self):
        """Test case for label_flow_export_policy1

        Label FlowExportPolicy object  # noqa: E501
        """
        pass

    def test_label_fwlog_policy(self):
        """Test case for label_fwlog_policy

        Label FwlogPolicy object  # noqa: E501
        """
        pass

    def test_label_fwlog_policy1(self):
        """Test case for label_fwlog_policy1

        Label FwlogPolicy object  # noqa: E501
        """
        pass

    def test_label_mirror_session(self):
        """Test case for label_mirror_session

        Label MirrorSession object  # noqa: E501
        """
        pass

    def test_label_mirror_session1(self):
        """Test case for label_mirror_session1

        Label MirrorSession object  # noqa: E501
        """
        pass

    def test_label_stats_alert_policy(self):
        """Test case for label_stats_alert_policy

        Label StatsAlertPolicy object  # noqa: E501
        """
        pass

    def test_label_stats_alert_policy1(self):
        """Test case for label_stats_alert_policy1

        Label StatsAlertPolicy object  # noqa: E501
        """
        pass

    def test_label_troubleshooting_session(self):
        """Test case for label_troubleshooting_session

        Label TroubleshootingSession object  # noqa: E501
        """
        pass

    def test_label_troubleshooting_session1(self):
        """Test case for label_troubleshooting_session1

        Label TroubleshootingSession object  # noqa: E501
        """
        pass

    def test_list_alert(self):
        """Test case for list_alert

        List Alert objects  # noqa: E501
        """
        pass

    def test_list_alert1(self):
        """Test case for list_alert1

        List Alert objects  # noqa: E501
        """
        pass

    def test_list_alert_destination(self):
        """Test case for list_alert_destination

        List AlertDestination objects  # noqa: E501
        """
        pass

    def test_list_alert_destination1(self):
        """Test case for list_alert_destination1

        List AlertDestination objects  # noqa: E501
        """
        pass

    def test_list_alert_policy(self):
        """Test case for list_alert_policy

        List AlertPolicy objects  # noqa: E501
        """
        pass

    def test_list_alert_policy1(self):
        """Test case for list_alert_policy1

        List AlertPolicy objects  # noqa: E501
        """
        pass

    def test_list_archive_request(self):
        """Test case for list_archive_request

        List ArchiveRequest objects  # noqa: E501
        """
        pass

    def test_list_archive_request1(self):
        """Test case for list_archive_request1

        List ArchiveRequest objects  # noqa: E501
        """
        pass

    def test_list_event_policy(self):
        """Test case for list_event_policy

        List EventPolicy objects  # noqa: E501
        """
        pass

    def test_list_event_policy1(self):
        """Test case for list_event_policy1

        List EventPolicy objects  # noqa: E501
        """
        pass

    def test_list_flow_export_policy(self):
        """Test case for list_flow_export_policy

        List FlowExportPolicy objects  # noqa: E501
        """
        pass

    def test_list_flow_export_policy1(self):
        """Test case for list_flow_export_policy1

        List FlowExportPolicy objects  # noqa: E501
        """
        pass

    def test_list_fwlog_policy(self):
        """Test case for list_fwlog_policy

        List FwlogPolicy objects  # noqa: E501
        """
        pass

    def test_list_fwlog_policy1(self):
        """Test case for list_fwlog_policy1

        List FwlogPolicy objects  # noqa: E501
        """
        pass

    def test_list_mirror_session(self):
        """Test case for list_mirror_session

        List MirrorSession objects  # noqa: E501
        """
        pass

    def test_list_mirror_session1(self):
        """Test case for list_mirror_session1

        List MirrorSession objects  # noqa: E501
        """
        pass

    def test_list_stats_alert_policy(self):
        """Test case for list_stats_alert_policy

        List StatsAlertPolicy objects  # noqa: E501
        """
        pass

    def test_list_stats_alert_policy1(self):
        """Test case for list_stats_alert_policy1

        List StatsAlertPolicy objects  # noqa: E501
        """
        pass

    def test_list_tech_support_request(self):
        """Test case for list_tech_support_request

        List TechSupportRequest objects  # noqa: E501
        """
        pass

    def test_list_troubleshooting_session(self):
        """Test case for list_troubleshooting_session

        List TroubleshootingSession objects  # noqa: E501
        """
        pass

    def test_list_troubleshooting_session1(self):
        """Test case for list_troubleshooting_session1

        List TroubleshootingSession objects  # noqa: E501
        """
        pass

    def test_update_alert(self):
        """Test case for update_alert

        Update Alert object  # noqa: E501
        """
        pass

    def test_update_alert1(self):
        """Test case for update_alert1

        Update Alert object  # noqa: E501
        """
        pass

    def test_update_alert_destination(self):
        """Test case for update_alert_destination

        Update AlertDestination object  # noqa: E501
        """
        pass

    def test_update_alert_destination1(self):
        """Test case for update_alert_destination1

        Update AlertDestination object  # noqa: E501
        """
        pass

    def test_update_alert_policy(self):
        """Test case for update_alert_policy

        Update AlertPolicy object  # noqa: E501
        """
        pass

    def test_update_alert_policy1(self):
        """Test case for update_alert_policy1

        Update AlertPolicy object  # noqa: E501
        """
        pass

    def test_update_audit_policy(self):
        """Test case for update_audit_policy

        Update AuditPolicy object  # noqa: E501
        """
        pass

    def test_update_audit_policy1(self):
        """Test case for update_audit_policy1

        Update AuditPolicy object  # noqa: E501
        """
        pass

    def test_update_event_policy(self):
        """Test case for update_event_policy

        Update EventPolicy object  # noqa: E501
        """
        pass

    def test_update_event_policy1(self):
        """Test case for update_event_policy1

        Update EventPolicy object  # noqa: E501
        """
        pass

    def test_update_flow_export_policy(self):
        """Test case for update_flow_export_policy

        Update FlowExportPolicy object  # noqa: E501
        """
        pass

    def test_update_flow_export_policy1(self):
        """Test case for update_flow_export_policy1

        Update FlowExportPolicy object  # noqa: E501
        """
        pass

    def test_update_fwlog_policy(self):
        """Test case for update_fwlog_policy

        Update FwlogPolicy object  # noqa: E501
        """
        pass

    def test_update_fwlog_policy1(self):
        """Test case for update_fwlog_policy1

        Update FwlogPolicy object  # noqa: E501
        """
        pass

    def test_update_mirror_session(self):
        """Test case for update_mirror_session

        Update MirrorSession object  # noqa: E501
        """
        pass

    def test_update_mirror_session1(self):
        """Test case for update_mirror_session1

        Update MirrorSession object  # noqa: E501
        """
        pass

    def test_update_stats_alert_policy(self):
        """Test case for update_stats_alert_policy

        Update StatsAlertPolicy object  # noqa: E501
        """
        pass

    def test_update_stats_alert_policy1(self):
        """Test case for update_stats_alert_policy1

        Update StatsAlertPolicy object  # noqa: E501
        """
        pass

    def test_update_troubleshooting_session(self):
        """Test case for update_troubleshooting_session

        Update TroubleshootingSession object  # noqa: E501
        """
        pass

    def test_update_troubleshooting_session1(self):
        """Test case for update_troubleshooting_session1

        Update TroubleshootingSession object  # noqa: E501
        """
        pass

    def test_watch_alert(self):
        """Test case for watch_alert

        Watch Alert objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_alert1(self):
        """Test case for watch_alert1

        Watch Alert objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_alert_destination(self):
        """Test case for watch_alert_destination

        Watch AlertDestination objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_alert_destination1(self):
        """Test case for watch_alert_destination1

        Watch AlertDestination objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_alert_policy(self):
        """Test case for watch_alert_policy

        Watch AlertPolicy objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_alert_policy1(self):
        """Test case for watch_alert_policy1

        Watch AlertPolicy objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_archive_request(self):
        """Test case for watch_archive_request

        Watch ArchiveRequest objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_archive_request1(self):
        """Test case for watch_archive_request1

        Watch ArchiveRequest objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_audit_policy(self):
        """Test case for watch_audit_policy

        Watch AuditPolicy objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_audit_policy1(self):
        """Test case for watch_audit_policy1

        Watch AuditPolicy objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_event_policy(self):
        """Test case for watch_event_policy

        Watch EventPolicy objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_event_policy1(self):
        """Test case for watch_event_policy1

        Watch EventPolicy objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_flow_export_policy(self):
        """Test case for watch_flow_export_policy

        Watch FlowExportPolicy objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_flow_export_policy1(self):
        """Test case for watch_flow_export_policy1

        Watch FlowExportPolicy objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_fwlog_policy(self):
        """Test case for watch_fwlog_policy

        Watch FwlogPolicy objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_fwlog_policy1(self):
        """Test case for watch_fwlog_policy1

        Watch FwlogPolicy objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_mirror_session(self):
        """Test case for watch_mirror_session

        Watch MirrorSession objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_mirror_session1(self):
        """Test case for watch_mirror_session1

        Watch MirrorSession objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_stats_alert_policy(self):
        """Test case for watch_stats_alert_policy

        Watch StatsAlertPolicy objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_stats_alert_policy1(self):
        """Test case for watch_stats_alert_policy1

        Watch StatsAlertPolicy objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_tech_support_request(self):
        """Test case for watch_tech_support_request

        Watch TechSupportRequest objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Cluster API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.cluster_host import ClusterHost
globals()['ClusterHost'] = ClusterHost
from pensando_dss.psm.psm.model.cluster_auto_msg_host_watch_helper_watch_event import ClusterAutoMsgHostWatchHelperWatchEvent


class TestClusterAutoMsgHostWatchHelperWatchEvent(unittest.TestCase):
    """ClusterAutoMsgHostWatchHelperWatchEvent unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testClusterAutoMsgHostWatchHelperWatchEvent(self):
        """Test ClusterAutoMsgHostWatchHelperWatchEvent"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ClusterAutoMsgHostWatchHelperWatchEvent()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Routing API reference

       # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.evpn_route_evpn_type2_route import EVPNRouteEVPNType2Route
from pensando_dss.psm.model.evpn_route_evpn_type5_route import EVPNRouteEVPNType5Route
globals()['EVPNRouteEVPNType2Route'] = EVPNRouteEVPNType2Route
globals()['EVPNRouteEVPNType5Route'] = EVPNRouteEVPNType5Route
from pensando_dss.psm.psm.model.routing_evpn_route import RoutingEVPNRoute


class TestRoutingEVPNRoute(unittest.TestCase):
    """RoutingEVPNRoute unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testRoutingEVPNRoute(self):
        """Test RoutingEVPNRoute"""
        # FIXME: construct object with mandatory attributes with example values
        # model = RoutingEVPNRoute()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Search API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.search_search_query import SearchSearchQuery
globals()['SearchSearchQuery'] = SearchSearchQuery
from pensando_dss.psm.psm.model.search_search_request import SearchSearchRequest


class TestSearchSearchRequest(unittest.TestCase):
    """SearchSearchRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSearchSearchRequest(self):
        """Test SearchSearchRequest"""
        # FIXME: construct object with mandatory attributes with example values
        # model = SearchSearchRequest()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Security API reference

       # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.api_list_meta import ApiListMeta
from pensando_dss.psm.model.security_security_group import SecuritySecurityGroup
globals()['ApiListMeta'] = ApiListMeta
globals()['SecuritySecurityGroup'] = SecuritySecurityGroup
from pensando_dss.psm.psm.model.security_security_group_list import SecuritySecurityGroupList


class TestSecuritySecurityGroupList(unittest.TestCase):
    """SecuritySecurityGroupList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSecuritySecurityGroupList(self):
        """Test SecuritySecurityGroupList"""
        # FIXME: construct object with mandatory attributes with example values
        # model = SecuritySecurityGroupList()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Preferences API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import psm
from pensando_dss.psm.api.preferences_v1_api import PreferencesV1Api  # noqa: E501


class TestPreferencesV1Api(unittest.TestCase):
    """PreferencesV1Api unit test stubs"""

    def setUp(self):
        self.api = PreferencesV1Api()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_ui_global_settings(self):
        """Test case for get_ui_global_settings

        Get UIGlobalSettings object  # noqa: E501
        """
        pass

    def test_get_ui_global_settings1(self):
        """Test case for get_ui_global_settings1

        Get UIGlobalSettings object  # noqa: E501
        """
        pass

    def test_label_ui_global_settings(self):
        """Test case for label_ui_global_settings

        Label UIGlobalSettings object  # noqa: E501
        """
        pass

    def test_label_ui_global_settings1(self):
        """Test case for label_ui_global_settings1

        Label UIGlobalSettings object  # noqa: E501
        """
        pass

    def test_update_ui_global_settings(self):
        """Test case for update_ui_global_settings

        Update UIGlobalSettings object  # noqa: E501
        """
        pass

    def test_update_ui_global_settings1(self):
        """Test case for update_ui_global_settings1

        Update UIGlobalSettings object  # noqa: E501
        """
        pass

    def test_watch_ui_global_settings(self):
        """Test case for watch_ui_global_settings

        Watch UIGlobalSettings objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_ui_global_settings1(self):
        """Test case for watch_ui_global_settings1

        Watch UIGlobalSettings objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Sysruntime API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.sysruntime_flow_status import SysruntimeFlowStatus
from pensando_dss.psm.model.sysruntime_fw_status import SysruntimeFwStatus
from pensando_dss.psm.model.sysruntime_ip_sec_status import SysruntimeIPSecStatus
globals()['SysruntimeFlowStatus'] = SysruntimeFlowStatus
globals()['SysruntimeFwStatus'] = SysruntimeFwStatus
globals()['SysruntimeIPSecStatus'] = SysruntimeIPSecStatus
from pensando_dss.psm.psm.model.sysruntime_hw_connection_status import SysruntimeHWConnectionStatus


class TestSysruntimeHWConnectionStatus(unittest.TestCase):
    """SysruntimeHWConnectionStatus unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSysruntimeHWConnectionStatus(self):
        """Test SysruntimeHWConnectionStatus"""
        # FIXME: construct object with mandatory attributes with example values
        # model = SysruntimeHWConnectionStatus()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Fwlog API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import psm
from pensando_dss.psm.api.fwlog_v1_api import FwlogV1Api  # noqa: E501


class TestFwlogV1Api(unittest.TestCase):
    """FwlogV1Api unit test stubs"""

    def setUp(self):
        self.api = FwlogV1Api()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_download_fw_log_file_content(self):
        """Test case for get_download_fw_log_file_content

        fwlog/v1/tenants/default/objects/<objectName>  # noqa: E501
        """
        pass

    def test_get_download_fw_log_file_content1(self):
        """Test case for get_download_fw_log_file_content1

        fwlog/v1/tenants/default/objects/<objectName>  # noqa: E501
        """
        pass

    def test_get_get_logs1(self):
        """Test case for get_get_logs1

        Queries firewall logs  # noqa: E501
        """
        pass

    def test_get_watch_logs(self):
        """Test case for get_watch_logs

        """
        pass

    def test_post_get_logs(self):
        """Test case for post_get_logs

        Queries firewall logs  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Staging API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.api_object_meta import ApiObjectMeta
from pensando_dss.psm.model.staging_buffer_spec import StagingBufferSpec
from pensando_dss.psm.model.staging_buffer_status import StagingBufferStatus
globals()['ApiObjectMeta'] = ApiObjectMeta
globals()['StagingBufferSpec'] = StagingBufferSpec
globals()['StagingBufferStatus'] = StagingBufferStatus
from pensando_dss.psm.psm.model.staging_buffer import StagingBuffer


class TestStagingBuffer(unittest.TestCase):
    """StagingBuffer unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testStagingBuffer(self):
        """Test StagingBuffer"""
        # FIXME: construct object with mandatory attributes with example values
        # model = StagingBuffer()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Sysruntime API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.sysruntime_conn_track_info import SysruntimeConnTrackInfo
from pensando_dss.psm.model.sysruntime_flow_info import SysruntimeFlowInfo
from pensando_dss.psm.model.sysruntime_telemetry_info import SysruntimeTelemetryInfo
globals()['SysruntimeConnTrackInfo'] = SysruntimeConnTrackInfo
globals()['SysruntimeFlowInfo'] = SysruntimeFlowInfo
globals()['SysruntimeTelemetryInfo'] = SysruntimeTelemetryInfo
from pensando_dss.psm.psm.model.sysruntime_flow_data import SysruntimeFlowData


class TestSysruntimeFlowData(unittest.TestCase):
    """SysruntimeFlowData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSysruntimeFlowData(self):
        """Test SysruntimeFlowData"""
        # FIXME: construct object with mandatory attributes with example values
        # model = SysruntimeFlowData()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Aggwatch API reference

       # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.psm.model.api_object_ref import ApiObjectRef


class TestApiObjectRef(unittest.TestCase):
    """ApiObjectRef unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testApiObjectRef(self):
        """Test ApiObjectRef"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ApiObjectRef()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Security API reference

       # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.security_dns import SecurityDns
from pensando_dss.psm.model.security_ftp import SecurityFtp
from pensando_dss.psm.model.security_icmp import SecurityIcmp
from pensando_dss.psm.model.security_msrpc import SecurityMsrpc
from pensando_dss.psm.model.security_sunrpc import SecuritySunrpc
globals()['SecurityDns'] = SecurityDns
globals()['SecurityFtp'] = SecurityFtp
globals()['SecurityIcmp'] = SecurityIcmp
globals()['SecurityMsrpc'] = SecurityMsrpc
globals()['SecuritySunrpc'] = SecuritySunrpc
from pensando_dss.psm.psm.model.security_alg import SecurityALG


class TestSecurityALG(unittest.TestCase):
    """SecurityALG unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSecurityALG(self):
        """Test SecurityALG"""
        # FIXME: construct object with mandatory attributes with example values
        # model = SecurityALG()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Cluster API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.api_object_meta import ApiObjectMeta
from pensando_dss.psm.model.cluster_cluster_profile_spec import ClusterClusterProfileSpec
globals()['ApiObjectMeta'] = ApiObjectMeta
globals()['ClusterClusterProfileSpec'] = ClusterClusterProfileSpec
from pensando_dss.psm.psm.model.cluster_cluster_profile import ClusterClusterProfile


class TestClusterClusterProfile(unittest.TestCase):
    """ClusterClusterProfile unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testClusterClusterProfile(self):
        """Test ClusterClusterProfile"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ClusterClusterProfile()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Search API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.security_ip_sec_policy_rule import SecurityIPSecPolicyRule
from pensando_dss.psm.model.security_sg_rule import SecuritySGRule
globals()['SecurityIPSecPolicyRule'] = SecurityIPSecPolicyRule
globals()['SecuritySGRule'] = SecuritySGRule
from pensando_dss.psm.psm.model.search_policy_match_entry import SearchPolicyMatchEntry


class TestSearchPolicyMatchEntry(unittest.TestCase):
    """SearchPolicyMatchEntry unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSearchPolicyMatchEntry(self):
        """Test SearchPolicyMatchEntry"""
        # FIXME: construct object with mandatory attributes with example values
        # model = SearchPolicyMatchEntry()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Monitoring API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.api_object_ref import ApiObjectRef
from pensando_dss.psm.model.monitoring_alert_reason import MonitoringAlertReason
from pensando_dss.psm.model.monitoring_alert_source import MonitoringAlertSource
from pensando_dss.psm.model.monitoring_audit_info import MonitoringAuditInfo
globals()['ApiObjectRef'] = ApiObjectRef
globals()['MonitoringAlertReason'] = MonitoringAlertReason
globals()['MonitoringAlertSource'] = MonitoringAlertSource
globals()['MonitoringAuditInfo'] = MonitoringAuditInfo
from pensando_dss.psm.psm.model.monitoring_alert_status import MonitoringAlertStatus


class TestMonitoringAlertStatus(unittest.TestCase):
    """MonitoringAlertStatus unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testMonitoringAlertStatus(self):
        """Test MonitoringAlertStatus"""
        # FIXME: construct object with mandatory attributes with example values
        # model = MonitoringAlertStatus()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Workload API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from pensando_dss.psm.api_client import ApiClient, Endpoint as _Endpoint
from pensando_dss.psm.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
import pensando_dss.psm as psm
from pensando_dss.psm.model.api_label import ApiLabel
from pensando_dss.psm.model.api_status import ApiStatus
from pensando_dss.psm.model.workload_auto_msg_endpoint_watch_helper import WorkloadAutoMsgEndpointWatchHelper
from pensando_dss.psm.model.workload_auto_msg_workload_watch_helper import WorkloadAutoMsgWorkloadWatchHelper
from pensando_dss.psm.model.workload_endpoint import WorkloadEndpoint
from pensando_dss.psm.model.workload_endpoint_list import WorkloadEndpointList
from pensando_dss.psm.model.workload_workload import WorkloadWorkload
from pensando_dss.psm.model.workload_workload_list import WorkloadWorkloadList


class WorkloadV1Api(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        def __abort_migration(
            self,
            o_tenant,
            body,
            **kwargs
        ):
            """Abort Workload Migration operation  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.abort_migration(o_tenant, body, async_req=True)
            >>> result = thread.get()

            Args:
                o_tenant (str):
                body (WorkloadWorkload):

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                WorkloadWorkload
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['o_tenant'] = \
                o_tenant
            kwargs['body'] = \
                body
            return self.call_with_http_info(**kwargs)

        self.abort_migration = _Endpoint(
            settings={
                'response_type': (WorkloadWorkload,),
                'auth': [],
                'endpoint_path': '/configs/workload/v1/tenant/{O.Tenant}/workloads/{O.Name}/AbortMigration',
                'operation_id': 'abort_migration',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'o_tenant',
                    'body',
                ],
                'required': [
                    'o_tenant',
                    'body',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'o_tenant':
                        (str,),
                    'body':
                        (WorkloadWorkload,),
                },
                'attribute_map': {
                    'o_tenant': 'O.Tenant',
                },
                'location_map': {
                    'o_tenant': 'path',
                    'body': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__abort_migration
        )

        def __abort_migration1(
            self,
            o_name,
            body,
            **kwargs
        ):
            """Abort Workload Migration operation  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.abort_migration1(o_name, body, async_req=True)
            >>> result = thread.get()

            Args:
                o_name (str):
                body (WorkloadWorkload):

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                WorkloadWorkload
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['o_name'] = \
                o_name
            kwargs['body'] = \
                body
            return self.call_with_http_info(**kwargs)

        self.abort_migration1 = _Endpoint(
            settings={
                'response_type': (WorkloadWorkload,),
                'auth': [],
                'endpoint_path': '/configs/workload/v1/workloads/{O.Name}/AbortMigration',
                'operation_id': 'abort_migration1',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'o_name',
                    'body',
                ],
                'required': [
                    'o_name',
                    'body',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'o_name':
                        (str,),
                    'body':
                        (WorkloadWorkload,),
                },
                'attribute_map': {
                    'o_name': 'O.Name',
                },
                'location_map': {
                    'o_name': 'path',
                    'body': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__abort_migration1
        )

        def __add_workload(
            self,
            o_tenant,
            body,
            **kwargs
        ):
            """Create Workload object  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.add_workload(o_tenant, body, async_req=True)
            >>> result = thread.get()

            Args:
                o_tenant (str):
                body (WorkloadWorkload):

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                WorkloadWorkload
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['o_tenant'] = \
                o_tenant
            kwargs['body'] = \
                body
            return self.call_with_http_info(**kwargs)

        self.add_workload = _Endpoint(
            settings={
                'response_type': (WorkloadWorkload,),
                'auth': [],
                'endpoint_path': '/configs/workload/v1/tenant/{O.Tenant}/workloads',
                'operation_id': 'add_workload',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'o_tenant',
                    'body',
                ],
                'required': [
                    'o_tenant',
                    'body',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'o_tenant':
                        (str,),
                    'body':
                        (WorkloadWorkload,),
                },
                'attribute_map': {
                    'o_tenant': 'O.Tenant',
                },
                'location_map': {
                    'o_tenant': 'path',
                    'body': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__add_workload
        )

        def __add_workload1(
            self,
            body,
            **kwargs
        ):
            """Create Workload object  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.add_workload1(body, async_req=True)
            >>> result = thread.get()

            Args:
                body (WorkloadWorkload):

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                WorkloadWorkload
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['body'] = \
                body
            return self.call_with_http_info(**kwargs)

        self.add_workload1 = _Endpoint(
            settings={
                'response_type': (WorkloadWorkload,),
                'auth': [],
                'endpoint_path': '/configs/workload/v1/workloads',
                'operation_id': 'add_workload1',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'body',
                ],
                'required': [
                    'body',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'body':
                        (WorkloadWorkload,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'body': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__add_workload1
        )

        def __delete_workload(
            self,
            o_tenant,
            **kwargs
        ):
            """Delete Workload object  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.delete_workload(o_tenant, async_req=True)
            >>> result = thread.get()

            Args:
                o_tenant (str):

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                WorkloadWorkload
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['o_tenant'] = \
                o_tenant
            return self.call_with_http_info(**kwargs)

        self.delete_workload = _Endpoint(
            settings={
                'response_type': (WorkloadWorkload,),
                'auth': [],
                'endpoint_path': '/configs/workload/v1/tenant/{O.Tenant}/workloads/{O.Name}',
                'operation_id': 'delete_workload',
                'http_method': 'DELETE',
                'servers': None,
            },
            params_map={
                'all': [
                    'o_tenant',
                ],
                'required': [
                    'o_tenant',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'o_tenant':
                        (str,),
                },
                'attribute_map': {
                    'o_tenant': 'O.Tenant',
                },
                'location_map': {
                    'o_tenant': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__delete_workload
        )

        def __delete_workload1(
            self,
            o_name,
            **kwargs
        ):
            """Delete Workload object  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.delete_workload1(o_name, async_req=True)
            >>> result = thread.get()

            Args:
                o_name (str):

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                WorkloadWorkload
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['o_name'] = \
                o_name
            return self.call_with_http_info(**kwargs)

        self.delete_workload1 = _Endpoint(
            settings={
                'response_type': (WorkloadWorkload,),
                'auth': [],
                'endpoint_path': '/configs/workload/v1/workloads/{O.Name}',
                'operation_id': 'delete_workload1',
                'http_method': 'DELETE',
                'servers': None,
            },
            params_map={
                'all': [
                    'o_name',
                ],
                'required': [
                    'o_name',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'o_name':
                        (str,),
                },
                'attribute_map': {
                    'o_name': 'O.Name',
                },
                'location_map': {
                    'o_name': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__delete_workload1
        )

        def __final_sync_migration(
            self,
            o_tenant,
            body,
            **kwargs
        ):
            """Initiates the final sync for the Workload Migration operation  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.final_sync_migration(o_tenant, body, async_req=True)
            >>> result = thread.get()

            Args:
                o_tenant (str):
                body (WorkloadWorkload):

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                WorkloadWorkload
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['o_tenant'] = \
                o_tenant
            kwargs['body'] = \
                body
            return self.call_with_http_info(**kwargs)

        self.final_sync_migration = _Endpoint(
            settings={
                'response_type': (WorkloadWorkload,),
                'auth': [],
                'endpoint_path': '/configs/workload/v1/tenant/{O.Tenant}/workloads/{O.Name}/FinalSyncMigration',
                'operation_id': 'final_sync_migration',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'o_tenant',
                    'body',
                ],
                'required': [
                    'o_tenant',
                    'body',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'o_tenant':
                        (str,),
                    'body':
                        (WorkloadWorkload,),
                },
                'attribute_map': {
                    'o_tenant': 'O.Tenant',
                },
                'location_map': {
                    'o_tenant': 'path',
                    'body': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__final_sync_migration
        )

        def __final_sync_migration1(
            self,
            o_name,
            body,
            **kwargs
        ):
            """Initiates the final sync for the Workload Migration operation  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.final_sync_migration1(o_name, body, async_req=True)
            >>> result = thread.get()

            Args:
                o_name (str):
                body (WorkloadWorkload):

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                WorkloadWorkload
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['o_name'] = \
                o_name
            kwargs['body'] = \
                body
            return self.call_with_http_info(**kwargs)

        self.final_sync_migration1 = _Endpoint(
            settings={
                'response_type': (WorkloadWorkload,),
                'auth': [],
                'endpoint_path': '/configs/workload/v1/workloads/{O.Name}/FinalSyncMigration',
                'operation_id': 'final_sync_migration1',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'o_name',
                    'body',
                ],
                'required': [
                    'o_name',
                    'body',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'o_name':
                        (str,),
                    'body':
                        (WorkloadWorkload,),
                },
                'attribute_map': {
                    'o_name': 'O.Name',
                },
                'location_map': {
                    'o_name': 'path',
                    'body': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__final_sync_migration1
        )

        def __finish_migration(
            self,
            o_tenant,
            body,
            **kwargs
        ):
            """Finish Workload Migration operation  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.finish_migration(o_tenant, body, async_req=True)
            >>> result = thread.get()

            Args:
                o_tenant (str):
                body (WorkloadWorkload):

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                WorkloadWorkload
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['o_tenant'] = \
                o_tenant
            kwargs['body'] = \
                body
            return self.call_with_http_info(**kwargs)

        self.finish_migration = _Endpoint(
            settings={
                'response_type': (WorkloadWorkload,),
                'auth': [],
                'endpoint_path': '/configs/workload/v1/tenant/{O.Tenant}/workloads/{O.Name}/FinishMigration',
                'operation_id': 'finish_migration',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'o_tenant',
                    'body',
                ],
                'required': [
                    'o_tenant',
                    'body',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'o_tenant':
                        (str,),
                    'body':
                        (WorkloadWorkload,),
                },
                'attribute_map': {
                    'o_tenant': 'O.Tenant',
                },
                'location_map': {
                    'o_tenant': 'path',
                    'body': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__finish_migration
        )

        def __finish_migration1(
            self,
            o_name,
            body,
            **kwargs
        ):
            """Finish Workload Migration operation  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.finish_migration1(o_name, body, async_req=True)
            >>> result = thread.get()

            Args:
                o_name (str):
                body (WorkloadWorkload):

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                WorkloadWorkload
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['o_name'] = \
                o_name
            kwargs['body'] = \
                body
            return self.call_with_http_info(**kwargs)

        self.finish_migration1 = _Endpoint(
            settings={
                'response_type': (WorkloadWorkload,),
                'auth': [],
                'endpoint_path': '/configs/workload/v1/workloads/{O.Name}/FinishMigration',
                'operation_id': 'finish_migration1',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'o_name',
                    'body',
                ],
                'required': [
                    'o_name',
                    'body',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'o_name':
                        (str,),
                    'body':
                        (WorkloadWorkload,),
                },
                'attribute_map': {
                    'o_name': 'O.Name',
                },
                'location_map': {
                    'o_name': 'path',
                    'body': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__finish_migration1
        )

        def __get_endpoint(
            self,
            o_tenant,
            **kwargs
        ):
            """Get Endpoint object  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_endpoint(o_tenant, async_req=True)
            >>> result = thread.get()

            Args:
                o_tenant (str):

            Keyword Args:
                t_kind (str): Kind represents the type of the API object.. [optional]
                meta_creation_time (datetime): CreationTime is the creation time of the object. System generated and updated, not updatable by user.. [optional]
                spec_node_uuid_list ([str]): NodeUUIDList has the list of DSCs where a EP is supposed to go to.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                WorkloadEndpoint
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['o_tenant'] = \
                o_tenant
            return self.call_with_http_info(**kwargs)

        self.get_endpoint = _Endpoint(
            settings={
                'response_type': (WorkloadEndpoint,),
                'auth': [],
                'endpoint_path': '/configs/workload/v1/tenant/{O.Tenant}/endpoints/{O.Name}',
                'operation_id': 'get_endpoint',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'o_tenant',
                    't_kind',
                    'meta_creation_time',
                    'spec_node_uuid_list',
                ],
                'required': [
                    'o_tenant',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'o_tenant':
                        (str,),
                    't_kind':
                        (str,),
                    'meta_creation_time':
                        (datetime,),
                    'spec_node_uuid_list':
                        ([str],),
                },
                'attribute_map': {
                    'o_tenant': 'O.Tenant',
                    't_kind': 'T.kind',
                    'meta_creation_time': 'meta.creation-time',
                    'spec_node_uuid_list': 'spec.node-uuid-list',
                },
                'location_map': {
                    'o_tenant': 'path',
                    't_kind': 'query',
                    'meta_creation_time': 'query',
                    'spec_node_uuid_list': 'query',
                },
                'collection_format_map': {
                    'spec_node_uuid_list': 'csv',
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_endpoint
        )

        def __get_endpoint1(
            self,
            o_name,
            **kwargs
        ):
            """Get Endpoint object  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_endpoint1(o_name, async_req=True)
            >>> result = thread.get()

            Args:
                o_name (str):

            Keyword Args:
                t_kind (str): Kind represents the type of the API object.. [optional]
                meta_creation_time (datetime): CreationTime is the creation time of the object. System generated and updated, not updatable by user.. [optional]
                spec_node_uuid_list ([str]): NodeUUIDList has the list of DSCs where a EP is supposed to go to.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                WorkloadEndpoint
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['o_name'] = \
                o_name
            return self.call_with_http_info(**kwargs)

        self.get_endpoint1 = _Endpoint(
            settings={
                'response_type': (WorkloadEndpoint,),
                'auth': [],
                'endpoint_path': '/configs/workload/v1/endpoints/{O.Name}',
                'operation_id': 'get_endpoint1',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'o_name',
                    't_kind',
                    'meta_creation_time',
                    'spec_node_uuid_list',
                ],
                'required': [
                    'o_name',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'o_name':
                        (str,),
                    't_kind':
                        (str,),
                    'meta_creation_time':
                        (datetime,),
                    'spec_node_uuid_list':
                        ([str],),
                },
                'attribute_map': {
                    'o_name': 'O.Name',
                    't_kind': 'T.kind',
                    'meta_creation_time': 'meta.creation-time',
                    'spec_node_uuid_list': 'spec.node-uuid-list',
                },
                'location_map': {
                    'o_name': 'path',
                    't_kind': 'query',
                    'meta_creation_time': 'query',
                    'spec_node_uuid_list': 'query',
                },
                'collection_format_map': {
                    'spec_node_uuid_list': 'csv',
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_endpoint1
        )

        def __get_workload(
            self,
            o_tenant,
            **kwargs
        ):
            """Get Workload object  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_workload(o_tenant, async_req=True)
            >>> result = thread.get()

            Args:
                o_tenant (str):

            Keyword Args:
                t_kind (str): Kind represents the type of the API object.. [optional]
                meta_creation_time (datetime): CreationTime is the creation time of the object. System generated and updated, not updatable by user.. [optional]
                propagation_status_pending_dscs ([str]): list of DSCs where propagation did not complete.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                WorkloadWorkload
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['o_tenant'] = \
                o_tenant
            return self.call_with_http_info(**kwargs)

        self.get_workload = _Endpoint(
            settings={
                'response_type': (WorkloadWorkload,),
                'auth': [],
                'endpoint_path': '/configs/workload/v1/tenant/{O.Tenant}/workloads/{O.Name}',
                'operation_id': 'get_workload',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'o_tenant',
                    't_kind',
                    'meta_creation_time',
                    'propagation_status_pending_dscs',
                ],
                'required': [
                    'o_tenant',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'o_tenant':
                        (str,),
                    't_kind':
                        (str,),
                    'meta_creation_time':
                        (datetime,),
                    'propagation_status_pending_dscs':
                        ([str],),
                },
                'attribute_map': {
                    'o_tenant': 'O.Tenant',
                    't_kind': 'T.kind',
                    'meta_creation_time': 'meta.creation-time',
                    'propagation_status_pending_dscs': 'propagation-status.pending-dscs',
                },
                'location_map': {
                    'o_tenant': 'path',
                    't_kind': 'query',
                    'meta_creation_time': 'query',
                    'propagation_status_pending_dscs': 'query',
                },
                'collection_format_map': {
                    'propagation_status_pending_dscs': 'csv',
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_workload
        )

        def __get_workload1(
            self,
            o_name,
            **kwargs
        ):
            """Get Workload object  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_workload1(o_name, async_req=True)
            >>> result = thread.get()

            Args:
                o_name (str):

            Keyword Args:
                t_kind (str): Kind represents the type of the API object.. [optional]
                meta_creation_time (datetime): CreationTime is the creation time of the object. System generated and updated, not updatable by user.. [optional]
                propagation_status_pending_dscs ([str]): list of DSCs where propagation did not complete.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                WorkloadWorkload
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['o_name'] = \
                o_name
            return self.call_with_http_info(**kwargs)

        self.get_workload1 = _Endpoint(
            settings={
                'response_type': (WorkloadWorkload,),
                'auth': [],
                'endpoint_path': '/configs/workload/v1/workloads/{O.Name}',
                'operation_id': 'get_workload1',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'o_name',
                    't_kind',
                    'meta_creation_time',
                    'propagation_status_pending_dscs',
                ],
                'required': [
                    'o_name',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'o_name':
                        (str,),
                    't_kind':
                        (str,),
                    'meta_creation_time':
                        (datetime,),
                    'propagation_status_pending_dscs':
                        ([str],),
                },
                'attribute_map': {
                    'o_name': 'O.Name',
                    't_kind': 'T.kind',
                    'meta_creation_time': 'meta.creation-time',
                    'propagation_status_pending_dscs': 'propagation-status.pending-dscs',
                },
                'location_map': {
                    'o_name': 'path',
                    't_kind': 'query',
                    'meta_creation_time': 'query',
                    'propagation_status_pending_dscs': 'query',
                },
                'collection_format_map': {
                    'propagation_status_pending_dscs': 'csv',
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_workload1
        )

        def __label_workload(
            self,
            o_tenant,
            body,
            **kwargs
        ):
            """Label Workload object  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.label_workload(o_tenant, body, async_req=True)
            >>> result = thread.get()

            Args:
                o_tenant (str):
                body (ApiLabel):

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                WorkloadWorkload
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['o_tenant'] = \
                o_tenant
            kwargs['body'] = \
                body
            return self.call_with_http_info(**kwargs)

        self.label_workload = _Endpoint(
            settings={
                'response_type': (WorkloadWorkload,),
                'auth': [],
                'endpoint_path': '/configs/workload/v1/tenant/{O.Tenant}/workloads/{O.Name}/label',
                'operation_id': 'label_workload',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'o_tenant',
                    'body',
                ],
                'required': [
                    'o_tenant',
                    'body',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'o_tenant':
                        (str,),
                    'body':
                        (ApiLabel,),
                },
                'attribute_map': {
                    'o_tenant': 'O.Tenant',
                },
                'location_map': {
                    'o_tenant': 'path',
                    'body': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__label_workload
        )

        def __label_workload1(
            self,
            o_name,
            body,
            **kwargs
        ):
            """Label Workload object  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.label_workload1(o_name, body, async_req=True)
            >>> result = thread.get()

            Args:
                o_name (str):
                body (ApiLabel):

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                WorkloadWorkload
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['o_name'] = \
                o_name
            kwargs['body'] = \
                body
            return self.call_with_http_info(**kwargs)

        self.label_workload1 = _Endpoint(
            settings={
                'response_type': (WorkloadWorkload,),
                'auth': [],
                'endpoint_path': '/configs/workload/v1/workloads/{O.Name}/label',
                'operation_id': 'label_workload1',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'o_name',
                    'body',
                ],
                'required': [
                    'o_name',
                    'body',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'o_name':
                        (str,),
                    'body':
                        (ApiLabel,),
                },
                'attribute_map': {
                    'o_name': 'O.Name',
                },
                'location_map': {
                    'o_name': 'path',
                    'body': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__label_workload1
        )

        def __list_endpoint(
            self,
            o_tenant,
            **kwargs
        ):
            """List Endpoint objects  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.list_endpoint(o_tenant, async_req=True)
            >>> result = thread.get()

            Args:
                o_tenant (str):

            Keyword Args:
                o_name (str): Name of the object, unique within a Namespace for scoped objects. Must start and end with alpha numeric and can have alphanumeric, -, _, . Length of string should be between 2 and 64.. [optional]
                o_creation_time (datetime): CreationTime is the creation time of the object. System generated and updated, not updatable by user.. [optional]
                field_change_selector ([str]): FieldChangeSelector specifies to generate a watch notification on change in field(s) specified.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                WorkloadEndpointList
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['o_tenant'] = \
                o_tenant
            return self.call_with_http_info(**kwargs)

        self.list_endpoint = _Endpoint(
            settings={
                'response_type': (WorkloadEndpointList,),
                'auth': [],
                'endpoint_path': '/configs/workload/v1/tenant/{O.Tenant}/endpoints',
                'operation_id': 'list_endpoint',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'o_tenant',
                    'o_name',
                    'o_creation_time',
                    'field_change_selector',
                ],
                'required': [
                    'o_tenant',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'o_tenant':
                        (str,),
                    'o_name':
                        (str,),
                    'o_creation_time':
                        (datetime,),
                    'field_change_selector':
                        ([str],),
                },
                'attribute_map': {
                    'o_tenant': 'O.Tenant',
                    'o_name': 'O.name',
                    'o_creation_time': 'O.creation-time',
                    'field_change_selector': 'field-change-selector',
                },
                'location_map': {
                    'o_tenant': 'path',
                    'o_name': 'query',
                    'o_creation_time': 'query',
                    'field_change_selector': 'query',
                },
                'collection_format_map': {
                    'field_change_selector': 'csv',
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__list_endpoint
        )

        def __list_endpoint1(
            self,
            **kwargs
        ):
            """List Endpoint objects  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.list_endpoint1(async_req=True)
            >>> result = thread.get()


            Keyword Args:
                o_name (str): Name of the object, unique within a Namespace for scoped objects. Must start and end with alpha numeric and can have alphanumeric, -, _, . Length of string should be between 2 and 64.. [optional]
                o_creation_time (datetime): CreationTime is the creation time of the object. System generated and updated, not updatable by user.. [optional]
                field_change_selector ([str]): FieldChangeSelector specifies to generate a watch notification on change in field(s) specified.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                WorkloadEndpointList
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            return self.call_with_http_info(**kwargs)

        self.list_endpoint1 = _Endpoint(
            settings={
                'response_type': (WorkloadEndpointList,),
                'auth': [],
                'endpoint_path': '/configs/workload/v1/endpoints',
                'operation_id': 'list_endpoint1',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'o_name',
                    'o_creation_time',
                    'field_change_selector',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'o_name':
                        (str,),
                    'o_creation_time':
                        (datetime,),
                    'field_change_selector':
                        ([str],),
                },
                'attribute_map': {
                    'o_name': 'O.name',
                    'o_creation_time': 'O.creation-time',
                    'field_change_selector': 'field-change-selector',
                },
                'location_map': {
                    'o_name': 'query',
                    'o_creation_time': 'query',
                    'field_change_selector': 'query',
                },
                'collection_format_map': {
                    'field_change_selector': 'csv',
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__list_endpoint1
        )

        def __list_workload(
            self,
            o_tenant,
            **kwargs
        ):
            """List Workload objects  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.list_workload(o_tenant, async_req=True)
            >>> result = thread.get()

            Args:
                o_tenant (str):

            Keyword Args:
                o_name (str): Name of the object, unique within a Namespace for scoped objects. Must start and end with alpha numeric and can have alphanumeric, -, _, . Length of string should be between 2 and 64.. [optional]
                o_creation_time (datetime): CreationTime is the creation time of the object. System generated and updated, not updatable by user.. [optional]
                field_change_selector ([str]): FieldChangeSelector specifies to generate a watch notification on change in field(s) specified.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                WorkloadWorkloadList
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['o_tenant'] = \
                o_tenant
            return self.call_with_http_info(**kwargs)

        self.list_workload = _Endpoint(
            settings={
                'response_type': (WorkloadWorkloadList,),
                'auth': [],
                'endpoint_path': '/configs/workload/v1/tenant/{O.Tenant}/workloads',
                'operation_id': 'list_workload',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'o_tenant',
                    'o_name',
                    'o_creation_time',
                    'field_change_selector',
                ],
                'required': [
                    'o_tenant',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'o_tenant':
                        (str,),
                    'o_name':
                        (str,),
                    'o_creation_time':
                        (datetime,),
                    'field_change_selector':
                        ([str],),
                },
                'attribute_map': {
                    'o_tenant': 'O.Tenant',
                    'o_name': 'O.name',
                    'o_creation_time': 'O.creation-time',
                    'field_change_selector': 'field-change-selector',
                },
                'location_map': {
                    'o_tenant': 'path',
                    'o_name': 'query',
                    'o_creation_time': 'query',
                    'field_change_selector': 'query',
                },
                'collection_format_map': {
                    'field_change_selector': 'csv',
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__list_workload
        )

        def __list_workload1(
            self,
            **kwargs
        ):
            """List Workload objects  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.list_workload1(async_req=True)
            >>> result = thread.get()


            Keyword Args:
                o_name (str): Name of the object, unique within a Namespace for scoped objects. Must start and end with alpha numeric and can have alphanumeric, -, _, . Length of string should be between 2 and 64.. [optional]
                o_creation_time (datetime): CreationTime is the creation time of the object. System generated and updated, not updatable by user.. [optional]
                field_change_selector ([str]): FieldChangeSelector specifies to generate a watch notification on change in field(s) specified.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                WorkloadWorkloadList
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            return self.call_with_http_info(**kwargs)

        self.list_workload1 = _Endpoint(
            settings={
                'response_type': (WorkloadWorkloadList,),
                'auth': [],
                'endpoint_path': '/configs/workload/v1/workloads',
                'operation_id': 'list_workload1',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'o_name',
                    'o_creation_time',
                    'field_change_selector',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'o_name':
                        (str,),
                    'o_creation_time':
                        (datetime,),
                    'field_change_selector':
                        ([str],),
                },
                'attribute_map': {
                    'o_name': 'O.name',
                    'o_creation_time': 'O.creation-time',
                    'field_change_selector': 'field-change-selector',
                },
                'location_map': {
                    'o_name': 'query',
                    'o_creation_time': 'query',
                    'field_change_selector': 'query',
                },
                'collection_format_map': {
                    'field_change_selector': 'csv',
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__list_workload1
        )

        def __start_migration(
            self,
            o_tenant,
            body,
            **kwargs
        ):
            """Start Workload Migration operation  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.start_migration(o_tenant, body, async_req=True)
            >>> result = thread.get()

            Args:
                o_tenant (str):
                body (WorkloadWorkload):

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                WorkloadWorkload
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['o_tenant'] = \
                o_tenant
            kwargs['body'] = \
                body
            return self.call_with_http_info(**kwargs)

        self.start_migration = _Endpoint(
            settings={
                'response_type': (WorkloadWorkload,),
                'auth': [],
                'endpoint_path': '/configs/workload/v1/tenant/{O.Tenant}/workloads/{O.Name}/StartMigration',
                'operation_id': 'start_migration',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'o_tenant',
                    'body',
                ],
                'required': [
                    'o_tenant',
                    'body',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'o_tenant':
                        (str,),
                    'body':
                        (WorkloadWorkload,),
                },
                'attribute_map': {
                    'o_tenant': 'O.Tenant',
                },
                'location_map': {
                    'o_tenant': 'path',
                    'body': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__start_migration
        )

        def __start_migration1(
            self,
            o_name,
            body,
            **kwargs
        ):
            """Start Workload Migration operation  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.start_migration1(o_name, body, async_req=True)
            >>> result = thread.get()

            Args:
                o_name (str):
                body (WorkloadWorkload):

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                WorkloadWorkload
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['o_name'] = \
                o_name
            kwargs['body'] = \
                body
            return self.call_with_http_info(**kwargs)

        self.start_migration1 = _Endpoint(
            settings={
                'response_type': (WorkloadWorkload,),
                'auth': [],
                'endpoint_path': '/configs/workload/v1/workloads/{O.Name}/StartMigration',
                'operation_id': 'start_migration1',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'o_name',
                    'body',
                ],
                'required': [
                    'o_name',
                    'body',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'o_name':
                        (str,),
                    'body':
                        (WorkloadWorkload,),
                },
                'attribute_map': {
                    'o_name': 'O.Name',
                },
                'location_map': {
                    'o_name': 'path',
                    'body': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__start_migration1
        )

        def __update_workload(
            self,
            o_tenant,
            body,
            **kwargs
        ):
            """Update Workload object  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.update_workload(o_tenant, body, async_req=True)
            >>> result = thread.get()

            Args:
                o_tenant (str):
                body (WorkloadWorkload):

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                WorkloadWorkload
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['o_tenant'] = \
                o_tenant
            kwargs['body'] = \
                body
            return self.call_with_http_info(**kwargs)

        self.update_workload = _Endpoint(
            settings={
                'response_type': (WorkloadWorkload,),
                'auth': [],
                'endpoint_path': '/configs/workload/v1/tenant/{O.Tenant}/workloads/{O.Name}',
                'operation_id': 'update_workload',
                'http_method': 'PUT',
                'servers': None,
            },
            params_map={
                'all': [
                    'o_tenant',
                    'body',
                ],
                'required': [
                    'o_tenant',
                    'body',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'o_tenant':
                        (str,),
                    'body':
                        (WorkloadWorkload,),
                },
                'attribute_map': {
                    'o_tenant': 'O.Tenant',
                },
                'location_map': {
                    'o_tenant': 'path',
                    'body': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__update_workload
        )

        def __update_workload1(
            self,
            o_name,
            body,
            **kwargs
        ):
            """Update Workload object  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.update_workload1(o_name, body, async_req=True)
            >>> result = thread.get()

            Args:
                o_name (str):
                body (WorkloadWorkload):

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                WorkloadWorkload
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['o_name'] = \
                o_name
            kwargs['body'] = \
                body
            return self.call_with_http_info(**kwargs)

        self.update_workload1 = _Endpoint(
            settings={
                'response_type': (WorkloadWorkload,),
                'auth': [],
                'endpoint_path': '/configs/workload/v1/workloads/{O.Name}',
                'operation_id': 'update_workload1',
                'http_method': 'PUT',
                'servers': None,
            },
            params_map={
                'all': [
                    'o_name',
                    'body',
                ],
                'required': [
                    'o_name',
                    'body',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'o_name':
                        (str,),
                    'body':
                        (WorkloadWorkload,),
                },
                'attribute_map': {
                    'o_name': 'O.Name',
                },
                'location_map': {
                    'o_name': 'path',
                    'body': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__update_workload1
        )

        def __watch_endpoint(
            self,
            o_tenant,
            **kwargs
        ):
            """Watch Endpoint objects. Supports WebSockets or HTTP long poll  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.watch_endpoint(o_tenant, async_req=True)
            >>> result = thread.get()

            Args:
                o_tenant (str):

            Keyword Args:
                o_name (str): Name of the object, unique within a Namespace for scoped objects. Must start and end with alpha numeric and can have alphanumeric, -, _, . Length of string should be between 2 and 64.. [optional]
                o_creation_time (datetime): CreationTime is the creation time of the object. System generated and updated, not updatable by user.. [optional]
                field_change_selector ([str]): FieldChangeSelector specifies to generate a watch notification on change in field(s) specified.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                WorkloadAutoMsgEndpointWatchHelper
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['o_tenant'] = \
                o_tenant
            return self.call_with_http_info(**kwargs)

        self.watch_endpoint = _Endpoint(
            settings={
                'response_type': (WorkloadAutoMsgEndpointWatchHelper,),
                'auth': [],
                'endpoint_path': '/configs/workload/v1/watch/tenant/{O.Tenant}/endpoints',
                'operation_id': 'watch_endpoint',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'o_tenant',
                    'o_name',
                    'o_creation_time',
                    'field_change_selector',
                ],
                'required': [
                    'o_tenant',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'o_tenant':
                        (str,),
                    'o_name':
                        (str,),
                    'o_creation_time':
                        (datetime,),
                    'field_change_selector':
                        ([str],),
                },
                'attribute_map': {
                    'o_tenant': 'O.Tenant',
                    'o_name': 'O.name',
                    'o_creation_time': 'O.creation-time',
                    'field_change_selector': 'field-change-selector',
                },
                'location_map': {
                    'o_tenant': 'path',
                    'o_name': 'query',
                    'o_creation_time': 'query',
                    'field_change_selector': 'query',
                },
                'collection_format_map': {
                    'field_change_selector': 'csv',
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__watch_endpoint
        )

        def __watch_endpoint1(
            self,
            **kwargs
        ):
            """Watch Endpoint objects. Supports WebSockets or HTTP long poll  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.watch_endpoint1(async_req=True)
            >>> result = thread.get()


            Keyword Args:
                o_name (str): Name of the object, unique within a Namespace for scoped objects. Must start and end with alpha numeric and can have alphanumeric, -, _, . Length of string should be between 2 and 64.. [optional]
                o_creation_time (datetime): CreationTime is the creation time of the object. System generated and updated, not updatable by user.. [optional]
                field_change_selector ([str]): FieldChangeSelector specifies to generate a watch notification on change in field(s) specified.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                WorkloadAutoMsgEndpointWatchHelper
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            return self.call_with_http_info(**kwargs)

        self.watch_endpoint1 = _Endpoint(
            settings={
                'response_type': (WorkloadAutoMsgEndpointWatchHelper,),
                'auth': [],
                'endpoint_path': '/configs/workload/v1/watch/endpoints',
                'operation_id': 'watch_endpoint1',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'o_name',
                    'o_creation_time',
                    'field_change_selector',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'o_name':
                        (str,),
                    'o_creation_time':
                        (datetime,),
                    'field_change_selector':
                        ([str],),
                },
                'attribute_map': {
                    'o_name': 'O.name',
                    'o_creation_time': 'O.creation-time',
                    'field_change_selector': 'field-change-selector',
                },
                'location_map': {
                    'o_name': 'query',
                    'o_creation_time': 'query',
                    'field_change_selector': 'query',
                },
                'collection_format_map': {
                    'field_change_selector': 'csv',
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__watch_endpoint1
        )

        def __watch_workload(
            self,
            o_tenant,
            **kwargs
        ):
            """Watch Workload objects. Supports WebSockets or HTTP long poll  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.watch_workload(o_tenant, async_req=True)
            >>> result = thread.get()

            Args:
                o_tenant (str):

            Keyword Args:
                o_name (str): Name of the object, unique within a Namespace for scoped objects. Must start and end with alpha numeric and can have alphanumeric, -, _, . Length of string should be between 2 and 64.. [optional]
                o_creation_time (datetime): CreationTime is the creation time of the object. System generated and updated, not updatable by user.. [optional]
                field_change_selector ([str]): FieldChangeSelector specifies to generate a watch notification on change in field(s) specified.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                WorkloadAutoMsgWorkloadWatchHelper
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['o_tenant'] = \
                o_tenant
            return self.call_with_http_info(**kwargs)

        self.watch_workload = _Endpoint(
            settings={
                'response_type': (WorkloadAutoMsgWorkloadWatchHelper,),
                'auth': [],
                'endpoint_path': '/configs/workload/v1/watch/tenant/{O.Tenant}/workloads',
                'operation_id': 'watch_workload',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'o_tenant',
                    'o_name',
                    'o_creation_time',
                    'field_change_selector',
                ],
                'required': [
                    'o_tenant',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'o_tenant':
                        (str,),
                    'o_name':
                        (str,),
                    'o_creation_time':
                        (datetime,),
                    'field_change_selector':
                        ([str],),
                },
                'attribute_map': {
                    'o_tenant': 'O.Tenant',
                    'o_name': 'O.name',
                    'o_creation_time': 'O.creation-time',
                    'field_change_selector': 'field-change-selector',
                },
                'location_map': {
                    'o_tenant': 'path',
                    'o_name': 'query',
                    'o_creation_time': 'query',
                    'field_change_selector': 'query',
                },
                'collection_format_map': {
                    'field_change_selector': 'csv',
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__watch_workload
        )

        def __watch_workload1(
            self,
            **kwargs
        ):
            """Watch Workload objects. Supports WebSockets or HTTP long poll  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.watch_workload1(async_req=True)
            >>> result = thread.get()


            Keyword Args:
                o_name (str): Name of the object, unique within a Namespace for scoped objects. Must start and end with alpha numeric and can have alphanumeric, -, _, . Length of string should be between 2 and 64.. [optional]
                o_creation_time (datetime): CreationTime is the creation time of the object. System generated and updated, not updatable by user.. [optional]
                field_change_selector ([str]): FieldChangeSelector specifies to generate a watch notification on change in field(s) specified.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                WorkloadAutoMsgWorkloadWatchHelper
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            return self.call_with_http_info(**kwargs)

        self.watch_workload1 = _Endpoint(
            settings={
                'response_type': (WorkloadAutoMsgWorkloadWatchHelper,),
                'auth': [],
                'endpoint_path': '/configs/workload/v1/watch/workloads',
                'operation_id': 'watch_workload1',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'o_name',
                    'o_creation_time',
                    'field_change_selector',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'o_name':
                        (str,),
                    'o_creation_time':
                        (datetime,),
                    'field_change_selector':
                        ([str],),
                },
                'attribute_map': {
                    'o_name': 'O.name',
                    'o_creation_time': 'O.creation-time',
                    'field_change_selector': 'field-change-selector',
                },
                'location_map': {
                    'o_name': 'query',
                    'o_creation_time': 'query',
                    'field_change_selector': 'query',
                },
                'collection_format_map': {
                    'field_change_selector': 'csv',
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__watch_workload1
        )



"""
    Objstore API reference

       # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.objstore_auto_msg_bucket_watch_helper_watch_event import ObjstoreAutoMsgBucketWatchHelperWatchEvent
globals()['ObjstoreAutoMsgBucketWatchHelperWatchEvent'] = ObjstoreAutoMsgBucketWatchHelperWatchEvent
from pensando_dss.psm.psm.model.objstore_auto_msg_bucket_watch_helper import ObjstoreAutoMsgBucketWatchHelper


class TestObjstoreAutoMsgBucketWatchHelper(unittest.TestCase):
    """ObjstoreAutoMsgBucketWatchHelper unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testObjstoreAutoMsgBucketWatchHelper(self):
        """Test ObjstoreAutoMsgBucketWatchHelper"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ObjstoreAutoMsgBucketWatchHelper()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from psm.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from pensando_dss.psm.model.api_agg_watch_options import ApiAggWatchOptions
from pensando_dss.psm.model.api_any import ApiAny
from pensando_dss.psm.model.api_kind_watch_options import ApiKindWatchOptions
from pensando_dss.psm.model.api_list_watch_options import ApiListWatchOptions
from pensando_dss.psm.model.api_object_meta import ApiObjectMeta
from pensando_dss.psm.model.api_object_ref import ApiObjectRef
from pensando_dss.psm.model.api_status import ApiStatus
from pensando_dss.psm.model.api_status_result import ApiStatusResult
from pensando_dss.psm.model.api_timestamp import ApiTimestamp
from pensando_dss.psm.model.api_watch_control import ApiWatchControl
from pensando_dss.psm.model.api_watch_event import ApiWatchEvent
from pensando_dss.psm.model.api_watch_event_list import ApiWatchEventList
from pensando_dss.psm.model.fields_requirement import FieldsRequirement
from pensando_dss.psm.model.fields_selector import FieldsSelector
from pensando_dss.psm.model.googleprotobuf_any import GoogleprotobufAny
from pensando_dss.psm.model.labels_requirement import LabelsRequirement
from pensando_dss.psm.model.labels_selector import LabelsSelector
from pensando_dss.psm.model.search_category_aggregation import SearchCategoryAggregation
from pensando_dss.psm.model.search_category_preview import SearchCategoryPreview
from pensando_dss.psm.model.search_entry import SearchEntry
from pensando_dss.psm.model.search_entry_list import SearchEntryList
from pensando_dss.psm.model.search_error import SearchError
from pensando_dss.psm.model.search_kind_aggregation import SearchKindAggregation
from pensando_dss.psm.model.search_kind_preview import SearchKindPreview
from pensando_dss.psm.model.search_policy_match_entries import SearchPolicyMatchEntries
from pensando_dss.psm.model.search_policy_match_entry import SearchPolicyMatchEntry
from pensando_dss.psm.model.search_policy_search_request import SearchPolicySearchRequest
from pensando_dss.psm.model.search_policy_search_response import SearchPolicySearchResponse
from pensando_dss.psm.model.search_rules_by_policy_name import SearchRulesByPolicyName
from pensando_dss.psm.model.search_search_query import SearchSearchQuery
from pensando_dss.psm.model.search_search_request import SearchSearchRequest
from pensando_dss.psm.model.search_search_response import SearchSearchResponse
from pensando_dss.psm.model.search_tenant_aggregation import SearchTenantAggregation
from pensando_dss.psm.model.search_tenant_preview import SearchTenantPreview
from pensando_dss.psm.model.search_text_requirement import SearchTextRequirement
from pensando_dss.psm.model.security_ip_sec_match_rule import SecurityIPSecMatchRule
from pensando_dss.psm.model.security_ip_sec_policy_rule import SecurityIPSecPolicyRule
from pensando_dss.psm.model.security_proto_port import SecurityProtoPort
from pensando_dss.psm.model.security_sg_rule import SecuritySGRule



"""
    Monitoring API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.api_object_meta import ApiObjectMeta
from pensando_dss.psm.model.monitoring_alert_policy_spec import MonitoringAlertPolicySpec
from pensando_dss.psm.model.monitoring_alert_policy_status import MonitoringAlertPolicyStatus
globals()['ApiObjectMeta'] = ApiObjectMeta
globals()['MonitoringAlertPolicySpec'] = MonitoringAlertPolicySpec
globals()['MonitoringAlertPolicyStatus'] = MonitoringAlertPolicyStatus
from pensando_dss.psm.psm.model.monitoring_alert_policy import MonitoringAlertPolicy


class TestMonitoringAlertPolicy(unittest.TestCase):
    """MonitoringAlertPolicy unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testMonitoringAlertPolicy(self):
        """Test MonitoringAlertPolicy"""
        # FIXME: construct object with mandatory attributes with example values
        # model = MonitoringAlertPolicy()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Sysruntime API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.api_list_meta import ApiListMeta
from pensando_dss.psm.model.sysruntime_hw_connection_get_response import SysruntimeHWConnectionGetResponse
globals()['ApiListMeta'] = ApiListMeta
globals()['SysruntimeHWConnectionGetResponse'] = SysruntimeHWConnectionGetResponse
from pensando_dss.psm.psm.model.sysruntime_connection_status import SysruntimeConnectionStatus


class TestSysruntimeConnectionStatus(unittest.TestCase):
    """SysruntimeConnectionStatus unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSysruntimeConnectionStatus(self):
        """Test SysruntimeConnectionStatus"""
        # FIXME: construct object with mandatory attributes with example values
        # model = SysruntimeConnectionStatus()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Security API reference

       # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.security_security_group import SecuritySecurityGroup
globals()['SecuritySecurityGroup'] = SecuritySecurityGroup
from pensando_dss.psm.psm.model.security_auto_msg_security_group_watch_helper_watch_event import SecurityAutoMsgSecurityGroupWatchHelperWatchEvent


class TestSecurityAutoMsgSecurityGroupWatchHelperWatchEvent(unittest.TestCase):
    """SecurityAutoMsgSecurityGroupWatchHelperWatchEvent unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSecurityAutoMsgSecurityGroupWatchHelperWatchEvent(self):
        """Test SecurityAutoMsgSecurityGroupWatchHelperWatchEvent"""
        # FIXME: construct object with mandatory attributes with example values
        # model = SecurityAutoMsgSecurityGroupWatchHelperWatchEvent()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Network API reference

       # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.network_ipam_pool_info import NetworkIPAMPoolInfo
globals()['NetworkIPAMPoolInfo'] = NetworkIPAMPoolInfo
from pensando_dss.psm.psm.model.network_ipam_config import NetworkIPAMConfig


class TestNetworkIPAMConfig(unittest.TestCase):
    """NetworkIPAMConfig unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testNetworkIPAMConfig(self):
        """Test NetworkIPAMConfig"""
        # FIXME: construct object with mandatory attributes with example values
        # model = NetworkIPAMConfig()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
